@@ -3,10 +3,8 @@ In order to keep a structure,
 we define here a NoCompression class to be used whenever we don't want to compress part of a dataset.
 """
 
-from .compressor_class import Compressor
 
-
-class NoCompression(Compressor):
+class NoCompression:
     """
     Compressor subclass for when we don't want any compression.
     """
